/*!
 * @file space_ship.h
 * Implements the Control of a Spaceship
 */

#ifndef _COLLISION_PROBE_H
#define _COLLISION_PROBE_H

#include "playable.h"

#include "vector.h"

class CollisionProbe : public Playable
{
  ObjectListDeclaration(CollisionProbe);

  public:
    CollisionProbe(const std::string& fileName);
    CollisionProbe(const TiXmlElement* root = NULL);
    virtual ~CollisionProbe();

    virtual void loadParams(const TiXmlElement* root);

    virtual void tick(float time);
    virtual void draw() const;

    virtual void process(const Event &event);

    virtual void enter() {}
    virtual void leave() {}
    virtual void setPlayDirection(const Quaternion& rot, float speed = 0.0f) {}

  private:
    void init();


    bool                  bUp;                //!< up button pressed.
    bool                  bDown;              //!< down button pressed.
    bool                  bLeft;              //!< left button pressed.
    bool                  bRight;             //!< right button pressed.
    bool                  bAscend;            //!< ascend button pressed.
    bool                  bDescend;           //!< descend button presses.
//    bool                  bFire;              //!< fire button pressed.(moved to playable)
    bool                  bRollL;             //!< rolling button pressed (left)
    bool                  bRollR;             //!< rolling button pressed (right)

    float                 xMouse;             //!< mouse moved in x-Direction
    float                 yMouse;             //!< mouse moved in y-Direction
    float                 mouseSensitivity;   //!< the mouse sensitivity
    int                   yInvert;
    int                   controlVelocityX;
    int                   controlVelocityY;

    Vector                localVelocity;      //!< velocity this entity flights with

};

#endif /* _SPACE_SHIPS_H */
